@@ -7,17 +7,10 @@ from django.template import Context
 from django.utils.http import urlencode
 from django.utils.safestring import mark_safe
 
-from ..components import render_alert
+from ..components import render_alert, render_button
 from ..core import css_url, get_bootstrap_setting, javascript_url, theme_url
-from ..forms import (
-    render_button,
-    render_field,
-    render_form,
-    render_form_errors,
-    render_formset,
-    render_formset_errors,
-    render_label,
-)
+from ..css import _css_class_list
+from ..forms import render_field, render_form, render_form_errors, render_formset, render_formset_errors, render_label
 from ..html import render_link_tag, render_script_tag
 from ..size import get_size_class
 from ..utils import render_template_file, url_replace_param
@@ -36,17 +29,30 @@ register = template.Library()
 @register.filter
 def bootstrap_setting(value):
     """
-    Get a setting.
+    Return django-bootstrap5 setting for use in in a template.
 
-    A simple way to read bootstrap settings in a template.
-    Please consider this filter private for now, do not use it in your own templates.
+    Please consider this filter private, do not use it in your own templates.
     """
     return get_bootstrap_setting(value)
 
 
+@register.simple_tag()
+def bootstrap_server_side_validation_class(widget):
+    """
+    Return server side validation class from a widget.
+
+    Please consider this tag private, do not use it in your own templates.
+    """
+    try:
+        css_classes = _css_class_list([widget["attrs"]["class"]])
+    except IndexError:
+        return ""
+    return " ".join([css_class for css_class in css_classes if css_class in ["is-valid", "is-invalid"]])
+
+
 @register.filter
 def bootstrap_message_alert_type(message):
-    """Return the alert type for a bootstrap message, defaults to `info`."""
+    """Return the alert type for a message, defaults to `info`."""
     try:
         level = message.level
     except AttributeError:
@@ -451,8 +457,8 @@ def bootstrap_field(*args, **kwargs):
 
             :default: ``''``. Can be changed :doc:`settings`
 
-        bound_css_class
-            CSS class used when the field is bound
+        success_css_class
+            CSS class used when the field has valid data
 
             :default: ``'has-success'``. Can be changed :doc:`settings`
 
@@ -544,7 +550,6 @@ def bootstrap_button(*args, **kwargs):
                 * ``'lg'``
                 * ``'large'``
 
-
         href
             Render the button as an ``<a>`` element. The ``href`` attribute is set with this value.
             If a ``button_type`` other than ``link`` is defined, specifying a ``href`` will throw a
@@ -556,6 +561,9 @@ def bootstrap_button(*args, **kwargs):
         value
             Value of the ``value`` attribute of the rendered element.
 
+        **kwargs
+            All other keywords arguments will be passed on as HTML attributes.
+
     **Usage**::
 
         {% bootstrap_button content %}
@@ -633,7 +641,6 @@ def bootstrap_messages(context, *args, **kwargs):
 
         {% bootstrap_messages %}
     """
-    # Force Context to dict
     if isinstance(context, Context):
         context = context.flatten()
     context.update({"message_constants": message_constants})
@@ -709,29 +716,23 @@ def get_pagination_context(
     pages_to_show = int(pages_to_show)
     if pages_to_show < 1:
         raise ValueError(f"Pagination pages_to_show should be a positive integer, you specified {pages_to_show}.")
+
     num_pages = page.paginator.num_pages
     current_page = page.number
-    half_page_num = int(floor(pages_to_show / 2))
-    if half_page_num < 0:
-        half_page_num = 0
-    first_page = current_page - half_page_num
-    if first_page <= 1:
-        first_page = 1
-    if first_page > 1:
-        pages_back = first_page - half_page_num
-        if pages_back < 1:
-            pages_back = 1
-    else:
-        pages_back = None
+
+    delta_pages = int(floor(pages_to_show / 2))
+
+    first_page = max(1, current_page - delta_pages)
+    pages_back = max(1, first_page - delta_pages) if first_page > 1 else None
+
     last_page = first_page + pages_to_show - 1
     if pages_back is None:
         last_page += 1
     if last_page > num_pages:
         last_page = num_pages
+
     if last_page < num_pages:
-        pages_forward = last_page + half_page_num
-        if pages_forward > num_pages:
-            pages_forward = num_pages
+        pages_forward = min(last_page + delta_pages, num_pages)
     else:
         pages_forward = None
         if first_page > 1:
@@ -740,6 +741,7 @@ def get_pagination_context(
             pages_back -= 1
         else:
             pages_back = None
+
     pages_shown = []
     for i in range(first_page, last_page + 1):
         pages_shown.append(i)
@@ -756,8 +758,6 @@ def get_pagination_context(
     if size:
         pagination_size_class = get_size_class(size, prefix="pagination", skip="md")
         if pagination_size_class:
-            if pagination_size_class not in ["pagination-sm", "pagination-lg"]:
-                raise ValueError("Invalid size for pagination, only 'sm' and 'lg' are allowed, '{size}' given.")
             pagination_css_classes.append(pagination_size_class)
 
     if justify_content:
